=========
Languages
=========
Application Languages
---------------------
The application is written in English.

.. note:: This application is written in English and uses AI machine translation for other languages.

The application is translated into the following languages:

* Arabic (ar)
* Azerbaijani (az)
* Bengali (bn)
* Catalan (ca)
* Czech (cs)
* Danish (da)
* German (de)
* Greek (el)
* Esperanto (eo)
* Spanish (es)
* Estonian (et)
* Basque (eu)
* Persian (fa)
* French (fr)
* Irish (ga)
* Galician (gl)
* Hebrew (he)
* Hindi (hi)
* Hungarian (hu)
* Indonesian (id)
* Italian (it)
* Japanese (ja)
* Korean (ko)
* Lithuanian (lt)
* Latvian (lv)
* Malay (ms)
* Norwegian (nb)
* Dutch (nl)
* Polish (pl)
* Portuguese (pt)
* Romanian (ro)
* Russian (ru)
* Slovak (sk)
* Slovenian (sl)
* Albanian (sq)
* Swedish (sv)
* Thai (th)
* Tagalog (tl)
* Turkish (tr)
* Ukranian (uk)
* Urdu (ur)
* Chinese (zh)

Documentation Languages
-----------------------
The documentation is written in English.

* English (en)
  `<https://transpolibre.org/en/>`_

.. note:: This documentation is written in English and uses AI machine translation for other languages.

It is machine (AI) translated into the following languages:

* Arabic (ar)
  `<https://transpolibre.org/ar/>`_

* Azerbaijani (az)
  `<https://transpolibre.org/az/>`_

* Bengali (bn)
  `<https://transpolibre.org/bn/>`_

* Catalan (ca)
  `<https://transpolibre.org/ca/>`_

* Czech (cs)
  `<https://transpolibre.org/cs/>`_

* Danish (da)
  `<https://transpolibre.org/da/>`_

* German (de)
  `<https://transpolibre.org/de/>`_

* Greek (el)
  `<https://transpolibre.org/el/>`_

* Esperanto (eo)
  `<https://transpolibre.org/eo/>`_

* Spanish (es)
  `<https://transpolibre.org/es/>`_

* Estonian (et)
  `<https://transpolibre.org/et/>`_

* Basque (eu)
  `<https://transpolibre.org/eu/>`_

* Persian (fa)
  `<https://transpolibre.org/fa/>`_

* French (fr)
  `<https://transpolibre.org/fr/>`_

* Irish (ga)
  `<https://transpolibre.org/ga/>`_

* Galician (gl)
  `<https://transpolibre.org/gl/>`_

* Hebrew (he)
  `<https://transpolibre.org/he/>`_

* Hindi (hi)
  `<https://transpolibre.org/hi/>`_

* Hungarian (hu)
  `<https://transpolibre.org/hu/>`_

* Indonesian (id)
  `<https://transpolibre.org/id/>`_

* Italian (it)
  `<https://transpolibre.org/it/>`_

* Japanese (ja)
  `<https://transpolibre.org/ja/>`_

* Korean (ko)
  `<https://transpolibre.org/ko/>`_

* Lithuanian (lt)
  `<https://transpolibre.org/lt/>`_

* Latvian (lv)
  `<https://transpolibre.org/lv/>`_

* Malay (ms)
  `<https://transpolibre.org/ms/>`_

* Norwegian (nb)
  `<https://transpolibre.org/nb/>`_

* Dutch (nl)
  `<https://transpolibre.org/nl/>`_

* Polish (pl)
  `<https://transpolibre.org/pl/>`_

* Portuguese (pt)
  `<https://transpolibre.org/pt/>`_

* Romanian (ro)
  `<https://transpolibre.org/ro/>`_

* Russian (ru)
  `<https://transpolibre.org/ru/>`_

* Slovak (sk)
  `<https://transpolibre.org/sk/>`_

* Slovenian (sl)
  `<https://transpolibre.org/sl/>`_

* Albanian (sq)
  `<https://transpolibre.org/sq/>`_

* Swedish (sv)
  `<https://transpolibre.org/sv/>`_

* Thai (th)
  `<https://transpolibre.org/th/>`_

* Tagalog (tl)
  `<https://transpolibre.org/tl/>`_

* Turkish (tr)
  `<https://transpolibre.org/tr/>`_

* Ukranian (uk)
  `<https://transpolibre.org/uk/>`_

* Urdu (ur)
  `<https://transpolibre.org/ur/>`_

* Chinese (zh)
  `<https://transpolibre.org/zh/>`_
